diff mbox series

[Bluez,61/62] android: Inclusive language for filtering devices

Message ID 20210813201256.Bluez.61.Ide58356fd72b10483a2b67591e71ce9f6a5b9973@changeid
State New
Headers show
Series Inclusive language changes | expand

Commit Message

Archie Pusaka Aug. 13, 2021, 12:18 p.m. UTC
From: Archie Pusaka <apusaka@chromium.org>

"accept list" is preferred, as reflected in the BT core spec v5.3.
Also prefer to use "blocked".
---

 android/bluetooth.c             | 18 +++++++++---------
 android/client/if-hf-client.c   |  2 +-
 android/hal-ipc-api.txt         |  2 +-
 android/hardware/bt_hf_client.h |  2 +-
 4 files changed, 12 insertions(+), 12 deletions(-)
diff --git a/android/client/if-hf-client.c b/android/client/if-hf-client.c
index e3793aaf0b..85444ab5da 100644
--- a/android/client/if-hf-client.c
+++ b/android/client/if-hf-client.c
@@ -98,7 +98,7 @@  SINTMAP(bthf_client_cmd_complete_t, -1, "(unknown)")
 	DELEMENT(BTHF_CLIENT_CMD_COMPLETE_ERROR_BUSY),
 	DELEMENT(BTHF_CLIENT_CMD_COMPLETE_ERROR_NO_ANSWER),
 	DELEMENT(BTHF_CLIENT_CMD_COMPLETE_ERROR_DELAYED),
-	DELEMENT(BTHF_CLIENT_CMD_COMPLETE_ERROR_BLACKLISTED),
+	DELEMENT(BTHF_CLIENT_CMD_COMPLETE_ERROR_BLOCKED),
 	DELEMENT(BTHF_CLIENT_CMD_COMPLETE_ERROR_CME),
 ENDMAP
 
diff --git a/android/hal-ipc-api.txt b/android/hal-ipc-api.txt
index e3b7798b3d..7886b6b827 100644
--- a/android/hal-ipc-api.txt
+++ b/android/hal-ipc-api.txt
@@ -2649,7 +2649,7 @@  Notifications:
 		                   0x03 = Error busy
 		                   0x04 = Error no answer
 		                   0x05 = Error delayed
-		                   0x06 = Error blacklisted
+		                   0x06 = Error blocked
 		                   0x07 = Error CME
 
 		Note: CME parameter is valid only for Error CME type
diff --git a/android/hardware/bt_hf_client.h b/android/hardware/bt_hf_client.h
index 4a0ec364b0..0ba5387330 100644
--- a/android/hardware/bt_hf_client.h
+++ b/android/hardware/bt_hf_client.h
@@ -98,7 +98,7 @@  typedef enum {
     BTHF_CLIENT_CMD_COMPLETE_ERROR_BUSY,
     BTHF_CLIENT_CMD_COMPLETE_ERROR_NO_ANSWER,
     BTHF_CLIENT_CMD_COMPLETE_ERROR_DELAYED,
-    BTHF_CLIENT_CMD_COMPLETE_ERROR_BLACKLISTED,
+    BTHF_CLIENT_CMD_COMPLETE_ERROR_BLOCKED,
     BTHF_CLIENT_CMD_COMPLETE_ERROR_CME
 } bthf_client_cmd_complete_t;
diff mbox series

Patch

diff --git a/android/bluetooth.c b/android/bluetooth.c
index b5f584eea2..611b717379 100644
--- a/android/bluetooth.c
+++ b/android/bluetooth.c
@@ -89,7 +89,7 @@  struct device {
 	bool le_paired;
 	bool le_bonded;
 
-	bool in_white_list;
+	bool in_accept_list;
 
 	bool connected;
 
@@ -1649,8 +1649,8 @@  bool bt_auto_connect_add(const bdaddr_t *addr)
 		return false;
 	}
 
-	if (dev->in_white_list) {
-		DBG("Device already in white list");
+	if (dev->in_accept_list) {
+		DBG("Device already in accept list");
 		return true;
 	}
 
@@ -1661,7 +1661,7 @@  bool bt_auto_connect_add(const bdaddr_t *addr)
 
 	if (mgmt_send(mgmt_if, MGMT_OP_ADD_DEVICE, adapter.index, sizeof(cp),
 						&cp, NULL, NULL, NULL) > 0) {
-		dev->in_white_list = true;
+		dev->in_accept_list = true;
 		return true;
 	}
 
@@ -1687,8 +1687,8 @@  void bt_auto_connect_remove(const bdaddr_t *addr)
 		return;
 	}
 
-	if (!dev->in_white_list) {
-		DBG("Device already removed from white list");
+	if (!dev->in_accept_list) {
+		DBG("Device already removed from accept list");
 		return;
 	}
 
@@ -1698,7 +1698,7 @@  void bt_auto_connect_remove(const bdaddr_t *addr)
 
 	if (mgmt_send(mgmt_if, MGMT_OP_REMOVE_DEVICE, adapter.index,
 				sizeof(cp), &cp, NULL, NULL, NULL) > 0) {
-		dev->in_white_list = false;
+		dev->in_accept_list = false;
 		return;
 	}
 
@@ -2194,8 +2194,8 @@  static void mgmt_device_unpaired_event(uint16_t index, uint16_t length,
 	update_device_state(dev, ev->addr.type, HAL_STATUS_SUCCESS, false,
 								false, false);
 
-	/* Unpaired device is removed from the white list */
-	dev->in_white_list = false;
+	/* Unpaired device is removed from the accept list */
+	dev->in_accept_list = false;
 }
 
 static void store_ltk(const bdaddr_t *dst, uint8_t bdaddr_type, bool central,